@@ -291,19 +291,6 @@ create_loading_model (void)
 	return retval;
 }
 
-static void
-ev_links_popup_cmd_search_outline (GSimpleAction *action,
-				   GVariant      *parameter,
-				   gpointer       ev_sidebar_links)
-{
-	GtkWidget *window;
-
-	window = gtk_widget_get_toplevel (GTK_WIDGET (ev_sidebar_links));
-	if (EV_IS_WINDOW (window)) {
-		ev_window_start_page_selector_search (EV_WINDOW (window));
-	}
-}
-
 static void
 ev_links_popup_cmd_print_section (GSimpleAction *action,
 				  GVariant      *parameter,
@@ -414,20 +401,18 @@ check_menu_sensitivity (GtkTreeView *treeview,
 		}
 	}
 
-	if (!selected_path) {
-		ev_sidebar_links_set_action_enabled (sidebar, "print-section", FALSE);
-		ev_sidebar_links_set_action_enabled (sidebar, "expand-element", FALSE);
-	}
-
-	if (is_list || !selected_path)
+	if (is_list)
 		return;
 
-	ev_sidebar_links_set_action_enabled (sidebar, "print-section", TRUE);
-
-	/* Enable 'Expand under this' only when 'this' element has any child */
+	/* Enable 'Expand under this' only when 'this' element has grandchildren */
 	gtk_tree_model_get_iter (model, &parent, selected_path);
 	if (gtk_tree_model_iter_children (model, &iter, &parent)) {
-		expand_under_sensitive = TRUE;
+		do {
+			if (gtk_tree_model_iter_has_child (model, &iter)) {
+				expand_under_sensitive = TRUE;
+				break;
+			}
+		} while (gtk_tree_model_iter_next (model, &iter));
 	}
 
 	ev_sidebar_links_set_action_enabled (sidebar, "expand-element", expand_under_sensitive);
@@ -454,20 +439,6 @@ check_menu_sensitivity (GtkTreeView *treeview,
 		ev_sidebar_links_set_action_enabled (sidebar, "collapse-all", TRUE);
 }
 
-static gboolean
-path_is_selected (GtkTreeView *treeview,
-                 GtkTreePath *path)
-{
-       GtkTreeModel *model;
-       GtkTreeSelection *selection;
-       GtkTreeIter iter;
-
-       model = gtk_tree_view_get_model (treeview);
-       selection = gtk_tree_view_get_selection (treeview);
-       return gtk_tree_model_get_iter (model, &iter, path) &&
-              gtk_tree_selection_iter_is_selected (selection, &iter);
-}
-
 static gboolean
 button_press_cb (GtkWidget *treeview,
                  GdkEventButton *event,
@@ -483,9 +454,8 @@ button_press_cb (GtkWidget *treeview,
 					    event->y, &path, NULL, NULL, NULL))
 		return GDK_EVENT_PROPAGATE;
 
-	if (! path_is_selected (GTK_TREE_VIEW (treeview), path))
-		path = NULL;
-
+	gtk_tree_view_set_cursor (GTK_TREE_VIEW (treeview),
+				  path, NULL, FALSE);
 	check_menu_sensitivity (GTK_TREE_VIEW (treeview), path, sidebar);
 	gtk_menu_popup_at_pointer (GTK_MENU (priv->popup),
 				   (GdkEvent *) event);
@@ -1010,7 +980,6 @@ ev_links_popup_cmd_expand_element (GSimpleAction *action,
 static GActionGroup *
 create_links_action_group (EvSidebarLinks *ev_sidebar_links) {
 	const GActionEntry popup_entries[] = {
-		{ "search-outline", ev_links_popup_cmd_search_outline },
 		{ "print-section", ev_links_popup_cmd_print_section },
 		{ "collapse-all", ev_links_popup_cmd_collapse_all },
 		{ "expand-all", ev_links_popup_cmd_expand_all },
@@ -1051,7 +1020,6 @@ ev_sidebar_links_construct (EvSidebarLinks *ev_sidebar_links)
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_NONE);
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (priv->tree_view), FALSE);
 	gtk_tree_view_set_tooltip_column (GTK_TREE_VIEW (priv->tree_view), 0);
-	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (priv->tree_view), FALSE);
 	gtk_container_add (GTK_CONTAINER (swindow), priv->tree_view);
 
 	gtk_box_pack_start (GTK_BOX (ev_sidebar_links), swindow, TRUE, TRUE, 0);
